get_1d_constraints: function to obtain the constrains to compute marginal...

View source: R/MECC_functions.R

get_1d_constraintsR Documentation

function to obtain the constrains to compute marginal distribution

Description

function to obtain the constrains to compute marginal distribution

Usage

get_1d_constraints(data_column)

Arguments

data_column

column containing the data of the analysed variable. Preferably the output of 'get_drought_series()'

Value

a vector with 2 values, *c1* and *c2*


pedroalencar1/DroughtSDF documentation built on May 8, 2023, 6:58 p.m.